=========
Tile sets
=========

.. currentmodule:: rgrow

---------------------
Constructing tilesets
---------------------

.. autosummary::
    :toctree: api/

    Tile
    TileSet
    TileSet.from_file    

--------------
Using tilesets
--------------

.. autosummary::
    :toctree: api/

    TileSet.to_simulation
    TileSet.run_window
    TileSet.run_ffs

-------
Options
-------